MOS visualization tool
----------------------

.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: http://www.astropy.org
    :alt: Powered by Astropy Badge

MOSViz is a quick-look analysis and visualization tool for multi-object spectroscopy (MOS).


License
-------

This project is Copyright (c) JDADF Developers and licensed under the terms of the BSD 3-Clause license. See the licenses folder for more information.
